from setuptools import setup

setup(name='meansort',
      version='0.8',
      description='Sorting algorithm by splitting a list by its mean/average.',
      url='https://github.com/dibsonthis/meansort',
      author='Adib Attie',
      author_email='adib.attie33@gmail.com',
      license='MIT',
      packages=['meansort'],
      install_requires=[

      ],
      zip_safe=False)
